==> skrooge_0.7.2.2.orig.tar.gz: skrooge-0.7.2.2/tests/suite_squish/tst_file/test.py <==
import os

def main():
    source(findFile("scripts", "skrooge_functions.py"))
    initSimple()
    
    waitForObject(":Untitled [modified] - skrooge.Save_QToolButton")
    clickButton(":Untitled [modified] - skrooge.Save_QToolButton")
    waitForObject(":Name:_KUrlComboBox_2")
    type(":Name:_KUrlComboBox_2", os.getenv('OUT')+"file.skg")
    waitForObject(":Save As – Skrooge.Save_KPushButton")
    clickButton(":Save As – Skrooge.Save_KPushButton")
    
    snooze(5)

    undo()
    redo()
    
    snooze(5)
    
    waitForObject(":file.skg [modified] - skrooge.Save_QToolButton")
    clickButton(":file.skg [modified] - skrooge.Save_QToolButton")
    waitForObject(":Untitled [modified] - skrooge_SKGMainPanel")
    type(":Untitled [modified] - skrooge_SKGMainPanel", "<Ctrl+K>")
    waitForObject(":New password.kPwd1_KLineEdit")
    type(":New password.kPwd1_KLineEdit", "test")
    waitForObject(":New password.kPwd1_KLineEdit")
    type(":New password.kPwd1_KLineEdit", "<Tab>")
    waitForObject(":New password.kPwd2_KLineEdit")
    type(":New password.kPwd2_KLineEdit", "test")
    waitForObject(":Skrooge.OK_KPushButton")
    clickButton(":Skrooge.OK_KPushButton")
    waitForObject(":file.skg [modified] - skrooge.Save_QToolButton")
    clickButton(":file.skg [modified] - skrooge.Save_QToolButton")
    
    waitForObject(":Untitled - skrooge_KTabBar")
    type(":Untitled - skrooge_KTabBar", "<Ctrl+O>")
    waitForObject(":Name:_KUrlComboBox")
    mouseClick(":Name:_KUrlComboBox", 89, 5, 0, Qt.LeftButton)
    waitForObject(":Name:_KUrlComboBox")
    type(":Name:_KUrlComboBox", os.getenv('OUT')+"file.skg")
    waitForObject(":Name:_KUrlComboBox")
    type(":Name:_KUrlComboBox", "<Return>")
    
    waitForObject(":New password.kPwd1_KLineEdit")
    type(":New password.kPwd1_KLineEdit", "test2")
    waitForObject(":Skrooge.OK_KPushButton")
    clickButton(":Skrooge.OK_KPushButton")
    
    waitForObject(":New password.kPwd1_KLineEdit")
    type(":New password.kPwd1_KLineEdit", "test")
    waitForObject(":Skrooge.OK_KPushButton")
    clickButton(":Skrooge.OK_KPushButton")

    waitForObject(":file.skg [modified] - skrooge_SKGMainPanel")
    sendEvent("QCloseEvent", ":file.skg [modified] - skrooge_SKGMainPanel")

==> skrooge_0.7.3.2.orig.tar.gz: skrooge-0.7.3.2/tests/suite_squish/tst_file/test.py <==
import os

def main():
    source(findFile("scripts", "skrooge_functions.py"))
    initSimple()
    
    waitForObject(":Untitled [modified] - skrooge.Save_QToolButton")
    clickButton(":Untitled [modified] - skrooge.Save_QToolButton")
    waitForObject(":Name:_KUrlComboBox_2")
    type(":Name:_KUrlComboBox_2", os.getenv('OUT')+"file.skg")
    waitForObject(":Save As – Skrooge.Save_KPushButton")
    clickButton(":Save As – Skrooge.Save_KPushButton")
    
    snooze(5)

    undo()
    redo()
    
    snooze(5)
    
    waitForObject(":file.skg [modified] - skrooge.Save_QToolButton")
    clickButton(":file.skg [modified] - skrooge.Save_QToolButton")
    waitForObject(":Untitled [modified] - skrooge_SKGMainPanel")
    type(":Untitled [modified] - skrooge_SKGMainPanel", "<Ctrl+K>")
    type(waitForObject(":linePassword_KLineEdit"), "test")
    type(waitForObject(":linePassword_KLineEdit"), "<Tab>")
    type(waitForObject(":lineVerifyPassword_KLineEdit"), "test")
    clickButton(waitForObject(":Skrooge.OK_KPushButton"))
    
    waitForObject(":file.skg [modified] - skrooge.Save_QToolButton")
    clickButton(":file.skg [modified] - skrooge.Save_QToolButton")
    
    waitForObject(":Untitled - skrooge_KTabBar")
    type(":Untitled - skrooge_KTabBar", "<Ctrl+O>")
    waitForObject(":Name:_KUrlComboBox")
    mouseClick(":Name:_KUrlComboBox", 89, 5, 0, Qt.LeftButton)
    waitForObject(":Name:_KUrlComboBox")
    type(":Name:_KUrlComboBox", os.getenv('OUT')+"file.skg")
    waitForObject(":Name:_KUrlComboBox")
    type(":Name:_KUrlComboBox", "<Return>")
    
    type(waitForObject(":passEdit_KLineEdit"), "test2")
    type(waitForObject(":passEdit_KLineEdit"), "<Return>")
    type(waitForObject(":passEdit_KLineEdit"), "test")
    type(waitForObject(":passEdit_KLineEdit"), "<Return>")

    waitForObject(":file.skg [modified] - skrooge_SKGMainPanel")
    sendEvent("QCloseEvent", ":file.skg [modified] - skrooge_SKGMainPanel")
